SET ECHO OFF
REM ***************************************************************************
REM ***************************** T R I V A D I S *****************************
REM ******************** Oracle Database 12c New Features *********************
REM ************************ http://www.trivadis.com **************************
REM ***************************************************************************
REM
REM Privileges..: User|DBA|SYSDBA
REM File name...: o122_app_container_clone_seed.sql
REM Author......: Markus Flechtner (fma)
REM Date........: March 2017
REM Description.: Application container: Clone App Seed to App PDB
REM Notes.......: . 
REM Parameters..: .
REM Requirements: Oracle Database 12c Release 1 - 12.2
REM
REM Changes:
REM DD.MM.YYYY Author Description
REM ===========================================================================
REM 
REM ***************************************************************************

SET ECHO ON TERMOUT ON SERVEROUTPUT ON PAGESIZE 100 LINESIZE 100

CLEAR SCREEN

spool log/o122_app_container_clone_seed.log

REM ===========================================================================
REM Demo: Create an Application PDB from Application Seed
REM ===========================================================================

pause

REM ===========================================================================
REM Connect to Application Root
REM ===========================================================================

alter session set container=DEMO;

pause


REM ===========================================================================
REM Create Application PDBs
REM ===========================================================================


create pluggable database DEMOPDB1 from demo$seed;

alter pluggable database DEMOPDB1 open;

create pluggable database DEMOPDB2 from demo$seed;

alter pluggable database DEMOPDB2 open;

pause

column pdb_name format a15

select
    pdb_name,
    con_id,
    application_root,
    application_pdb,
    application_seed,
    application_root_con_id,
    application_clone
from cdb_pdbs;

pause


REM ===========================================================================
REM Connect to Application PDB as SCOTT
REM ===========================================================================

rem connect scott/tiger@kereru.markusdba.net:1521/DEMOPDB1.markusdba.net
connect scott/tiger@nf12cdba.trivadistraining.com:1521/DEMOPDB1.trivadistraining.com

pause

REM ===========================================================================
REM take a look at the tables
REM ===========================================================================

desc scott.emp

select * from scott.dept;

update scott.dept set loc='SEATTLE' where loc='CHICAGO';

pause

REM ===========================================================================
REM Insert some employee data
REM ===========================================================================

INSERT INTO EMP VALUES
        (7369, 'SMITH',  'CLERK',     7902,
        TO_DATE('17-DEC-1980', 'DD-MON-YYYY'),  800, NULL, 20);
INSERT INTO EMP VALUES
        (7499, 'ALLEN',  'SALESMAN',  7698,
        TO_DATE('20-FEB-1981', 'DD-MON-YYYY'), 1600,  300, 30);
INSERT INTO EMP VALUES
        (7521, 'WARD',   'SALESMAN',  7698,
        TO_DATE('22-FEB-1981', 'DD-MON-YYYY'), 1250,  500, 30);
INSERT INTO EMP VALUES
        (7566, 'JONES',  'MANAGER',   7839,
        TO_DATE('2-APR-1981', 'DD-MON-YYYY'),  2975, NULL, 20);
INSERT INTO EMP VALUES
        (7654, 'MARTIN', 'SALESMAN',  7698,
        TO_DATE('28-SEP-1981', 'DD-MON-YYYY'), 1250, 1400, 30);
INSERT INTO EMP VALUES
        (7698, 'BLAKE',  'MANAGER',   7839,
        TO_DATE('1-MAY-1981', 'DD-MON-YYYY'),  2850, NULL, 30);
INSERT INTO EMP VALUES
        (7782, 'CLARK',  'MANAGER',   7839,
        TO_DATE('9-JUN-1981', 'DD-MON-YYYY'),  2450, NULL, 10);
INSERT INTO EMP VALUES
        (7788, 'SCOTT',  'ANALYST',   7566,
        TO_DATE('09-DEC-1982', 'DD-MON-YYYY'), 3000, NULL, 20);
INSERT INTO EMP VALUES
        (7839, 'KING',   'PRESIDENT', NULL,
        TO_DATE('17-NOV-1981', 'DD-MON-YYYY'), 5000, NULL, 10);
INSERT INTO EMP VALUES
        (7844, 'TURNER', 'SALESMAN',  7698,
        TO_DATE('8-SEP-1981', 'DD-MON-YYYY'),  1500,    0, 30);
INSERT INTO EMP VALUES
        (7876, 'ADAMS',  'CLERK',     7788,
        TO_DATE('12-JAN-1983', 'DD-MON-YYYY'), 1100, NULL, 20);
INSERT INTO EMP VALUES
        (7900, 'JAMES',  'CLERK',     7698,
        TO_DATE('3-DEC-1981', 'DD-MON-YYYY'),   950, NULL, 30);
INSERT INTO EMP VALUES
        (7902, 'FORD',   'ANALYST',   7566,
        TO_DATE('3-DEC-1981', 'DD-MON-YYYY'),  3000, NULL, 20);
INSERT INTO EMP VALUES
        (7934, 'MILLER', 'CLERK',     7782,
        TO_DATE('23-JAN-1982', 'DD-MON-YYYY'), 1300, NULL, 10);

commit;

pause


REM ===========================================================================
REM Create a local table
REM ===========================================================================

CREATE TABLE BONUS
        (ENAME VARCHAR2(10),
         JOB   VARCHAR2(9),
         SAL   NUMBER,
         COMM  NUMBER);


pause

REM ===========================================================================
REM back to Application Root DEMO
REM ===========================================================================

connect / as sysdba
alter session set container=demo;



pause
 
 
column pdb_name format a15
 
select
    pdb_name,
    con_id,
    application_root,
    application_pdb,
    application_seed,
    application_root_con_id,
    application_clone
from cdb_pdbs
order by con_id;

pause

column app_name format a36
column app_version format a12
column app_status format a12


select
    con_uid,
    app_id, 
    con_id,
    app_name,
    app_version,
    app_status
from CDB_APP_PDB_STATUS
order by con_uid;

pause


spool off
