SET ECHO OFF
REM ***************************************************************************
REM ***************************** T R I V A D I S *****************************
REM ******************** Oracle Database 12c New Features *********************
REM ************************ http://www.trivadis.com **************************
REM ***************************************************************************
REM
REM Privileges..: User|DBA|SYSDBA
REM File name...: o122_app_container_upgrade_app_v2.sql
REM Author......: Markus Flechtner
REM Date........: March 2017
REM Description.: Upgrade an Application Container
REM Notes.......: .
REM Parameters..: .
REM Requirements: Oracle Database 12c Release 1 - 12.2
REM
REM Changes:
REM DD.MM.YYYY Author Description
REM ===========================================================================
REM 
REM ***************************************************************************

SET ECHO ON TERMOUT ON SERVEROUTPUT ON PAGESIZE 100 LINESIZE 100

CLEAR SCREEN

spool log/o122_app_container_upgrade_app_v2.log

REM ===========================================================================
REM Demo: Upgrade Application in Application Root to Version 2
REM ===========================================================================

alter session set container=DEMO;

alter pluggable database application DEMOAPP
begin upgrade '1.0'  to '2.0';

pause

REM ===========================================================================
REM Create shared table (Sharing=extended data)
REM ===========================================================================

CREATE TABLE scott.ZIP_CODES Sharing=Extended data
(
COUNTRY_ISO_CODE    varchar2(2),
ZIP_CODE            varchar2(5),
CITY                varchar2(40)
)
;

alter table scott.zip_codes 
add constraint PK$ZIP_CODES primary key (COUNTRY_ISO_CODE,ZIP_CODE) using index;

REM .. insert some data

insert into scott.zip_codes values ('CH','4051','Basel');
insert into scott.zip_codes values ('CH','3015','Bern');
insert into scott.zip_codes values ('CH','5200','Brugg');
insert into scott.zip_codes values ('DE','40227','Duesseldorf');
insert into scott.zip_codes values ('DE','60528','Frankfurt am Main');
insert into scott.zip_codes values ('DE','79111','Freiburg im Breisgau');
insert into scott.zip_codes values ('CH','1219','Genf');
insert into scott.zip_codes values ('DE','22761','Hamburg');
insert into scott.zip_codes values ('DK','2750','Ballerup');
insert into scott.zip_codes values ('CH','1005','Lausanne');
insert into scott.zip_codes values ('DE','81829','Muenchen');
insert into scott.zip_codes values ('DE','70565','Stuttgart');
insert into scott.zip_codes values ('AT','1200','Wien');
insert into scott.zip_codes values ('CH','8152','Glattbrugg');

commit;

pause 

REM ===========================================================================
REM create a view
REM ===========================================================================

create or replace view scott.v_emp_dept sharing=metadata
as
select 
	e.empno,
	e.ename,
	d.deptno,
	d.dname
from scott.emp e,scott.dept d
where d.deptno=e.deptno
;

create table scott.no_sharing sharing=none
(
id	number,
text	varchar2(10)
)
;


alter pluggable database application DEMOAPP end upgrade to '2.0';

pause

rem connect scott/tiger@kereru.markusdba.net:1521/DEMOPDB1.markusdba.net

REM ===========================================================================
REM Check the data dictionary
REM ===========================================================================

column pdb_name format a15

select
    pdb_name,
    con_id,
    application_root,
    application_pdb,
    application_seed,
    application_root_con_id,
    application_clone
from cdb_pdbs;

pause

column table_name format a30

select table_name,extended_data_link,extended_data_link_map 
from dba_tables where owner='SCOTT';

pause

column app_name format a36
column app_version format a12


select
    con_id,
    app_name,
    app_version
from CDB_APP_VERSIONS;


spool off






