SET ECHO OFF
REM ***************************************************************************
REM ***************************** T R I V A D I S *****************************
REM ******************** Oracle Database 12c New Features *********************
REM ************************ http://www.trivadis.com **************************
REM ***************************************************************************
REM
REM Privileges..: User|DBA|SYSDBA
REM File name...: o122_app_root_install_app_v1.sql
REM Author......: Markus Flechtner 
REM Date........: March 2017
REM Description.: creates application root for Application Containers
REM Notes.......: .
REM Parameters..: .
REM Requirements: Oracle Database 12c Release 1 - 12.2
REM
REM Changes:
REM DD.MM.YYYY Author Description
REM ===========================================================================
REM 
REM ***************************************************************************

SET ECHO ON TERMOUT ON SERVEROUTPUT ON PAGESIZE 100 LINESIZE 100

CLEAR SCREEN

spool log/o122_app_root_install_app_v1.log

REM ===========================================================================
REM Demo: Install Application Version 1.0 in Application Root
REM ===========================================================================
pause

REM ===========================================================================
REM Connect to the application root
REM ===========================================================================

alter session set container=DEMO;


REM ***************************************************************************
REM Begin installation
REM ***************************************************************************
execute dbms_application_info.set_module(module_name=>'INSTALL_V1',action_name=>null);

alter pluggable database application DEMOAPP 
begin install '1.0';

pause

REM ***************************************************************************
REM Create Tablespace (OMF)
REM ***************************************************************************
create tablespace
APP_USER_DATA
datafile size 50M;

pause

REM ***************************************************************************
REM Create Application Common User SCOTT
REM ***************************************************************************

REM Common_User_Prefix is empty in the Application Root
REM Although it is set to "C##" in CDB$ROOT
show parameter common_user_prefix

REM .. no prefix for the application user

pause

create user scott identified by tiger
default tablespace app_user_data
temporary tablespace temp
quota unlimited on app_user_data 
container=all;


grant create session to scott container=all; 
grant resource to scott container=all; 

pause


REM ***************************************************************************
REM Create local table (Sharing=metadata)
REM ***************************************************************************

connect scott/tiger@nf12cdba.trivadistraining.com:1521/DEMO.trivadistraining.com
rem connect scott/tiger@kereru.markusdba.net:1521/DEMO.markusdba.net
execute dbms_application_info.set_module(module_name=>'INSTALL_V1',action_name=>null);

CREATE TABLE scott.EMP sharing=metadata
       (EMPNO NUMBER(4) NOT NULL,
        ENAME VARCHAR2(10),
        JOB VARCHAR2(9),
        MGR NUMBER(4),
        HIREDATE DATE,
        SAL NUMBER(7, 2),
        COMM NUMBER(7, 2),
        DEPTNO NUMBER(2));

pause

REM ***************************************************************************
REM Create shared table (Sharing=data)
REM ***************************************************************************

CREATE TABLE scott.DEPT sharing=data
       (DEPTNO NUMBER(2),
        DNAME VARCHAR2(14),
        LOC VARCHAR2(13) );

pause
        
INSERT INTO scott.DEPT VALUES (10, 'ACCOUNTING', 'NEW YORK');
INSERT INTO scott.DEPT VALUES (20, 'RESEARCH',   'DALLAS');
INSERT INTO scott.DEPT VALUES (30, 'SALES',      'CHICAGO');
INSERT INTO scott.DEPT VALUES (40, 'OPERATIONS', 'BOSTON');


commit;

pause


REM ***************************************************************************
REM End installation
REM ***************************************************************************

connect / as sysdba
alter session set container=demo;
execute dbms_application_info.set_module(module_name=>'INSTALL_V1',action_name=>null);

alter pluggable database application DEMOAPP
end install '1.0';

pause

spool off






